# Overview

Types
Xmgrace
Graph
Axes
Set
Others
Functions

# Sheet 1: Types

Fonts |  |  | Lines |
1 | Times-Roman |  | 1 | full
2 | Times-Italic |  | 2 | dot
3 | Times-BoldItalic |  | 3 | dash
4 | Helvetica |  | 4 | longdash
5 | Helvetica-Oblique |  | 5 | dot-dash
6 | Helvetica-Bold |  | 6 | dot-longdash
7 | Helvetica-BoldOblique |  | 7 | dot-dot-dash
8 | Courirer |  | 8 | dot-dash-dash
9 | Courier-Oblique |  |  |
10 | Courier-Bold |  |  |
11 | Courier-BoldOblique |  |  |
12 | Symbol |  |  |
13 | ZapfDingbats |  |  |
Colors |  |  | Symbols |
0 | white |  | 0 | none
1 | black |  | 1 | circle
2 | red |  | 2 | square
3 | green |  | 3 | diamond
4 | blue |  | 4 | triangle up
5 | yellow |  | 5 | triangle left
6 | brown |  | 6 | triangle down
7 | grey |  | 7 | triangle right
8 | violet |  | 8 | plus
9 | cyan |  | 9 | X
10 | magenta |  | 10 | star
11 | orange |  | 11 | char
12 | indigo |  |  |
13 | maroon |  |  |
14 | turquoise |  |  |
15 | green4 |  |  |

# Sheet 2: Xmgrace

Xmgrace |  |  |  |  |
| Graph | See details | It's list of graph objects |  |
| ngraph | 1 | # of graphs |  |
| Set | See details |  |  |
| nset | 1 | # of sets |  |
| Font | See details |  |  |
| nfont | 14 |  |  |
| lfont |  |  |  |
| Colors | See details |  |  |
| ncolor |  |  |  |
| String | See details |  |  |
| nstring |  |  |  |
| Line | See details |  |  |
| nlne |  |  |  |
| version | '50102' | Xmgrace version |  |
| pyversion | '1.1.3b' | Python module version |  |
| link_page | Off |  |  |
| linewidth | 1 |  |  |
| linestyle | 1 |  |  |
| color | 1 |  |  |
| pattern | 1 |  |  |
| font | 0 |  |  |
| char_size | 1 |  |  |
| symbol_size | 1 |  |  |
| sformat | '"%16.8g"' |  |  |
| background_color | 0 |  |  |
| R | See details |  |  |
| nr | 0 | # of regions |  |
| page |  |  |  |
|  | x | 792 | pixels |
|  | y | 612 |  |
|  | scroll | 5 |  |
|  | inout | 5 |  |
|  | background_fill | 'on' | 'off' |
| timestamp |  |  |  |
|  | status | 'off' | 'on' |
|  | x | 0.03 |  |
|  | y | 0.03 |  |
|  | color | 1 |  |
|  | rot | 0 |  |
|  | font | 0 |  |
|  | char_size | 1 |  |
|  | default | Mon Oct 18 16:55:50 1999 |  |
| date |  |  |  |
|  | reference | 0 |  |
|  | wrap |  |  |
|  |  | status | 'off' | 'on'
|  |  | year | 1950 |

# Sheet 3: Graph

Graph | (parent='xmgrace object,ymin,ymax,xmin,xmax) |  |  |  |
| xmin | '' | not recommended, just for backward compatibily |  |
| xmax | '' |  |  |
| ymin | '' |  |  |
| ymax | '' |  |  |
| vxmin | 0.15 | In % of page |  |
| vxmax | 0.85 | " |  |
| vymin | 0.15 | " |  |
| vymax | 0.85 | " |  |
| status | 'on' | 'off' |  |
| hidden | 'false' | 'true' |  |
| type | 'xy' | ' chart','polar','pie','smith','fixed' |  |
| stacked | 'false' | 'true' |  |
| stack_world | [0,0,0,0] |  |  |
| bar_hgap | 0 |  |  |
| titel | '' |  |  |
| stitle | '' |  |  |
| fixedpoint |  |  |  |
|  | status | 'off' | 'on' |
|  | type | 0 |  |
|  | xy | [0,0] |  |
|  | format | 'general' |  |
|  | prec | 6 |  |
| tit |  |  |  |
|  | font | parent=0 | from xmgrace object |
|  | size | 1.5 |  |
|  | color | parent=1 | from xmgrace object |
| stit |  |  |  |
|  | font | parent=0 | from xmgrace object |
|  | size | 1 |  |
|  | color | parent=1 | from xmgrace object |
| Set | It's a list of set object, associated with the graph |  |  |
|  | see special sheet |  |  |
| x/yaxis |  |  | Identical for 'xaxis and 'yaxis |
|  | see special sheet |  |  |
| legend |  |  |  |
|  | status | 'on' | 'off' |
|  | loctype | 'view' | 'world' |
|  | x | 0.85 | % of the page |
|  | y | 0.8 | % of the page |
|  | box |  |  |
|  |  | color | parent=1 | from xmgrace object
|  |  | pattern | parent=1 | from xmgrace object
|  |  | linewidth | parent=1 | from xmgrace object
|  |  | linestyle | parent=1 | from xmgrace object
|  |  | fcolor | 0 |
|  |  | fpattern | parent=1 | from xmgrace object
|  | font | parent=0 |  |
|  | char_size | parent=1 |  |
|  | color | parent=1 |  |
|  | length | 4 |  |
|  | vgap | 1 |  |
|  | hgap | 1 |  |
|  | Invert | 'false' | 'true' |
| frame |  |  |  |
|  | type | 0 |  |
|  | linestyle | parent=1 |  |
|  | linewidth | parent=1 |  |
|  | color | parent=1 |  |
|  | pattern | parent=1 |  |
|  | background_color |  | parent=0 |
|  | background_pattern |  | parent=1 |

# Sheet 4: Axes

x/yaxis |  |  | Identical for 'xaxis and 'yaxis |  |
| label | ' |  |  |
| scale | 'normal' | 'logarithmic','Reciprocal' |  |
| Invert | 'off' | 'on' |  |
| status | 'false' |  |  |
| zero | 'false' | 'true' |  |
| xoffset | 0 |  |  |
| yoffset | 0 |  |  |
| offset | [] | you can pass the xoffset and yoffset values here instead |  |
| altaxis | 'off' | 'on' |  |
| min | 0 | can be changed when creating the graph |  |
| max | 1 | " |  |
| bar |  |  |  |
|  | status | 'on' | 'off' |
|  | color | parent=1 | from xmgrace object |
|  | linestyle | parent=1 | from xmgrace object |
|  | linewidth | parent=1 | from xmgrace object |
| lbl |  |  |  |
|  | layout | 'para' | 'perp' (// or perpendicular) |
|  | char_size | parent=1 | from xmgrace object |
|  | font | parent=0 | from xmgrace object |
|  | color | parent=1 | from xmgrace object |
|  | place |  |  |
|  |  | loc | 'auto' |
|  |  | side | 'normal' | 'oposite', 'both' : where to put the labels
| tick |  |  |  |
|  | status | 'on' | 'off' |
|  | inc | 0.5 | # or whatever increment value (i.e. Every 0.5 here) |
|  | minor_ticks | 1 | # of sub tickmarks between the major ones |
|  | place_rounded | 'true' | 'false' |
|  | nsub | 6 | # autotick division (for place rounded ?) |
|  | orientation | 'in' | 'out','both' |
|  | place | 'normal' | 'oposite','both' |
|  | spec |  |  |
|  |  | loc | [] | list of loc for ticks or dictionary: loc/label
|  |  | values | [] | labels(values) list to write at each loc or dic
|  |  | type | 'both' | 'none','ticks'
|  | major |  |  |
|  |  | size | 1 |
|  |  | color | parent=1 | from xmgrace object
|  |  | linewidth | parent=1 | from xmgrace object
|  |  | linestyle | parent=1 | from xmgrace object
|  |  | grid | 'off' | 'on', draw the grid lines
|  | minor |  |  |
|  |  | size | 0.5 |
|  |  | color | parent=1 | from xmgrace object
|  |  | linewidth | parent=1 | from xmgrace object
|  |  | linestyle | parent=1 | from xmgrace object
|  |  | 'grid' | 'off' | 'on', draw the grid lines
|  | label |  |  |
|  |  | status | 'on' | 'off'
|  |  | prec | 5 |
|  |  | format | 'general' |
|  |  | append | '' |
|  |  | prepend | '' |
|  |  | angle | 0 |
|  |  | skip | 0 |
|  |  | stagger | 0 |
|  |  | place | 'normal' | 'opposite','both'
|  |  | offset | 'auto' | [0.,0.], // and perpendicular offsets
|  |  | sign | 'normal' |
|  |  | start | 'auto' | or value
|  |  | stop | 'auto' | or value
|  |  | char_size | parent=1 |
|  |  | font | parent=0 |
|  |  | color | parent=1 |
|  |  | type | 'auto' |
|  | type | 'auto' | 'spec','zmean' (for area weighted zonal mean betw -1 and 1) |
| alt | 'off' | 'on' |  |

# Sheet 5: Set

Set |  |  |  |  |  |
| graph | 0 | can be passed at creation time |  |  |
| hidden | 'false' | 'true' |  |  |
| type | 'xy' | xydx','xydy','xydxdx','xydydy','xydxdy','xydxdxdydy','bar','bardy','bardydy |  |  |
|  |  | 'xyhilo','xyz','xyr','xysize','xycolor','xycolpat','xyvmap','xyboxplot' |  |  |
| symbol |  |  |  |  |
|  | type | 0 |  |  |
|  | size | parent=symbol_size=1 |  | from xmgrace object |
|  | color | parent=background_color=0 |  | from xmgrace object |
|  | pattern | parent=1 | from xmgrace object |  |
|  | fcolor | parent=1 | can be passed at creation time |  |
|  | fpattern | parent=1 | from xmgrace object |  |
|  | linestyle | parent=1 | from xmgrace object |  |
|  | linewidth | parent=1 | from xmgrace object |  |
|  | char | 65 |  |  |
|  | char_font | parent=0 | from xmgrace object |  |
|  | skip | 0 |  |  |
| line |  |  |  |  |
|  | type | 1 |  |  |
|  | linestyle | parent=1 | from xmgrace object |  |
|  | linewidth | parent=1 | from xmgrace object |  |
|  | color | parent=1 | can be passed at creation time |  |
|  | pattern | parent=1 | from xmgrace object |  |
| baseline |  |  |  |  |
|  | type | 0 |  |  |
|  | status | 'off' | 'on' |  |
| dropline | 'off' | 'on' |  |  |
| fill |  |  |  |  |
|  | type | 0 | 0:'none',1:'as polygone',2:'to baseline' |  | # only, no string allowed
|  | rule | 0 | 0:'winding',1:'even-odd' |  | # only, no string allowed
|  | color | parent=1 | can be passed at creation time |  |
|  | pattern | parent=1 | from xmgrace object |  |
| avalue |  |  |  |  |
|  | status | 'off' | 'on' |  |
|  | type | 2 |  |  |
|  | char_size | parent=1 | from xmgrace object |  |
|  | font | parent=0 | from xmgrace object |  |
|  | color | parent=1 | can be passed at creation time |  |
|  | rot | 0 |  |  |
|  | format | 'general' |  |  |
|  | prec | 3 |  |  |
|  | prepend | '' |  |  |
|  | append | '' |  |  |
|  | xoffset | 0 |  |  |
|  | yoffset | 0 |  |  |
|  | offset | [] | you can pass the xoffset and yoffset values here instead |  |
| error |  |  |  |  |
|  | status | 'off' | 'on' |  |
|  | type | 'both' | 'normal','opposite' |  |
|  | length | 1 |  |  |
|  | linewidth | parent=1 | from xmgrace object |  |
|  | linsestyle | parent=1 | from xmgrace object |  |
|  | riser |  |  |  |
|  |  | linewidth | parent=1 | from xmgrace object |
|  |  | linsestyle | parent=1 | from xmgrace object |

# Sheet 6: Others

Color | (name) |  |  |
| name | 'black' | can pass any name |
| rgb | [0,0,0] | red green blue values |
| change() |  | function to change the color, expect a name then reset rgb's |
Region |  |  |  |
| status | 'off' | 'on' |
| type | 'above' | 'polyi','polyo','above','below','left','right','horizi','horizo','veri','verto' |
| linestyle | parent=1 |  |
| linewidth | parent=1 |  |
| color | parent=1 |  |
| link | 'all' |  |
| xy | [] | list of [x,y] coordinates to def the polygone |
| line | [0,0,0,0] |  |
String | (x,y,text,[color],[char_size],[font],[rot],[just]) |  |  |
| x | argument |  |
| y | argument |  |
| text | argument |  |
| status | 'on' | 'off' |
| xy | [x,y] |  |
| loctype | 'view' | 'world' |
| color | parent=1 |  |
| char_size | parent=1 |  |
| font | parent=0 |  |
| rot | 0 |  |
| just | 14 |  |
Line | (x1,y1,x2,y2,[color],[lwidth],[lstyl], |  |  |
| [arrow],[atyp],[algth],[alyo]) |  |  |
| status | 'on' | 'off' |
| loctype | 'view' | 'world' |
| color | parent=1 |  |
| linewidth | parent=1 |  |
| linestyle | parent=1 |  |
| arrow |  |  |
|  | status | 'off' | 'on'
|  | type | 0 | 0:'line',1:'filled',2:'opaque'
|  | length | 2 |
|  | layout | [1.,1.] |
| x1 |  |  |
| y1 |  |  |
| x2 |  |  |
| y2 |  |  |
| xy | [x1,y1,x2,y2] |  |

# Sheet 7: Functions

Function | Arguments | Return | Comment
Objecthelp | (object) | return object.__doc__,str(object) | return the doc and the print(object)
add_r | () | None | Adds a region
list_font | () | List of string | Return a list with the font names
add_font | (name) | None | Add a font, make sur it works with xmgrace first
add_color | (name) | None | Add a color object to x.Color
add_graph | () | None | Add a graph to x.Graph list
creategraph | () | None | Add a graph to x.Graph list
add_set | (color=-1,graph=0) | None | Add a set to x.Set list
|  |  | Color=-1, automatically use color=nset
|  |  | Graph sets the graph where to plot it
add_string | (x,y,text,color=-1,char_size=-1,font=-1, | None | Add a string to x.String
| rot=0,just=14) |  | -1 means use x.attribute
add_line | (x1,y1,x2,y2,color=-1,lwidth=-1,lstyl=-1 | None | Add a line to x.Line
| arrow='off',atyp=0,algth=2,alyo=[1,1]) |  | -1 means use x.attribute
read_parameter | (parameterfile) | None | Reads in a parameter file and applies it,DOESN'T update the x.attributes !
make_parameter | () | List of strings | Creates a list of strings representing the parameter file of x
plot | (list of datasets) | None | Plot the datasets, must be in a list
|  |  | And each dataset must have a .getdimattribute(0,'values')
output | (fnm,out='PostScript') | None | Create an image file at the out format
ps,postscript | (fnm,[color='color'],[level='level2'], | None | Create a postscript file
| [docdata='8bit'],[xoffset=0],[yoffset=0],[mediafeed='auto'],[hwresolution='off'],[dpi=300]) |  |
jpeg | (fnm,[color='color'],[optimize='off'], |  | Create a jpeg file
| [quality=75],[smoothing=0],[baseline='off'],[progressive='on'],[dct='islow'],[dpi=72]) |  |
pdf | (fnm,[pdf='1.3'],[compression=4],[dpi=72]) |  | Create a pdf file
eps | (fnm,[color='color'],[level='level2'],[bbox='tight'],[docdata='8bit'],[dpi=300]) |  | Create eps file
mif | (fnm,[dpi=72]) | None | Create a metafile file
svg | (fnm,[dpi=72]) | None |
pnm | (fnm,[format='ppm'],[rawbit='on'],[dpi=72]) | None | Create a pnm file, format are: color='ppm',grayscale='pgm',bw='pbm'
png | (fnm,[interlaced='off'],[transparent='on'],[compression=4],[dpi=72]): |  | Create a png file
metafile | (fnm,[dpi=72]) | None | Create a .gmf file
close | () | None | Exit xmgrace
redraw | () | None | Flush the xmgrace queue and redraw the plot
update | () | None | Recreate the plot from the xmgrace object, looses all change made from the GUI
command | (cmd) | None | Pass a command to the xmgrace interpreter, same as (cmd)
is_open | () | 1 | Returns 1 if xmgrace is open, 0 if closed
exit | () | None | Exit xmgrace (kill the pipe)
portrait | () | None | Put the xmgrace template in portrait mode (i.e. Switch x and y dim if x>y)
landscape | () | None | Put the xmgrace template in landscape mode (i.e. Switch x and y dim if y>x)
orientation | () | None | Switch between portrait or landscape mode
col | (name) | String | Return the color index for the color name passed (as a string)
lin | (name) | String | Return the xmgrace value for the line type you passed (as a string)
whichsets | (list_of_graph) | List of integer | Return all the sets associated with the Graph(s) you passed
list | () | None | Return list of settable attributes and their value, avalilable at any level